@@ -12,6 +12,8 @@ use uzers::UsersCache;
 
 use crate::fs::feature::git::GitCache;
 use crate::fs::{fields as f, File};
+use crate::options::vars::EZA_WINDOWS_ATTRIBUTES;
+use crate::options::Vars;
 use crate::output::cell::TextCell;
 use crate::output::color_scale::ColorScaleInformation;
 #[cfg(unix)]
@@ -29,6 +31,7 @@ pub struct Options {
     pub time_format: TimeFormat,
     pub user_format: UserFormat,
     pub group_format: GroupFormat,
+    pub flags_format: FlagsFormat,
     pub columns: Columns,
 }
 
@@ -49,6 +52,7 @@ pub struct Columns {
     pub subdir_git_repos_no_stat: bool,
     pub octal: bool,
     pub security_context: bool,
+    pub file_flags: bool,
 
     // Defaults to true:
     pub permissions: bool,
@@ -98,6 +102,10 @@ impl Columns {
             columns.push(Column::Group);
         }
 
+        if self.file_flags {
+            columns.push(Column::FileFlags);
+        }
+
         #[cfg(target_os = "linux")]
         if self.security_context {
             columns.push(Column::SecurityContext);
@@ -157,6 +165,7 @@ pub enum Column {
     Octal,
     #[cfg(unix)]
     SecurityContext,
+    FileFlags,
 }
 
 /// Each column can pick its own **Alignment**. Usually, numbers are
@@ -214,16 +223,18 @@ impl Column {
             Self::Octal => "Octal",
             #[cfg(unix)]
             Self::SecurityContext => "Security Context",
+            Self::FileFlags => "Flags",
         }
     }
 }
 
 /// Formatting options for file sizes.
 #[allow(clippy::enum_variant_names)]
-#[derive(PartialEq, Eq, Debug, Copy, Clone)]
+#[derive(PartialEq, Eq, Debug, Default, Copy, Clone)]
 pub enum SizeFormat {
     /// Format the file size using **decimal** prefixes, such as “kilo”,
     /// “mega”, or “giga”.
+    #[default]
     DecimalBytes,
 
     /// Format the file size using **binary** prefixes, such as “kibi”,
@@ -252,12 +263,6 @@ pub enum GroupFormat {
     Smart,
 }
 
-impl Default for SizeFormat {
-    fn default() -> Self {
-        Self::DecimalBytes
-    }
-}
-
 /// The types of a file’s time fields. These three fields are standard
 /// across most (all?) operating systems.
 #[derive(PartialEq, Eq, Debug, Copy, Clone)]
@@ -297,6 +302,28 @@ impl TimeType {
     }
 }
 
+/// How display file flags.
+#[derive(PartialEq, Eq, Debug, Default, Copy, Clone)]
+pub enum FlagsFormat {
+    /// Display flags as comma seperated descriptions
+    #[default]
+    Long,
+    /// Display flags as single character abbreviations (Windows only)
+    Short,
+}
+
+impl FlagsFormat {
+    pub(crate) fn deduce<V: Vars>(vars: &V) -> FlagsFormat {
+        vars.get(EZA_WINDOWS_ATTRIBUTES)
+            .and_then(|v| match v.to_ascii_lowercase().to_str() {
+                Some("short") => Some(FlagsFormat::Short),
+                Some("long") => Some(FlagsFormat::Long),
+                _ => None,
+            })
+            .unwrap_or_default()
+    }
+}
+
 /// Fields for which of a file’s time fields should be displayed in the
 /// columns output.
 ///
@@ -378,6 +405,7 @@ pub struct Table<'a> {
     user_format: UserFormat,
     #[cfg(unix)]
     group_format: GroupFormat,
+    flags_format: FlagsFormat,
     git: Option<&'a GitCache>,
 }
 
@@ -411,6 +439,7 @@ impl<'a> Table<'a> {
             user_format: options.user_format,
             #[cfg(unix)]
             group_format: options.group_format,
+            flags_format: options.flags_format,
         }
     }
 
@@ -512,6 +541,7 @@ impl<'a> Table<'a> {
             ),
             #[cfg(unix)]
             Column::SecurityContext => file.security_context().render(self.theme),
+            Column::FileFlags => file.flags().render(self.theme.ui.flags, self.flags_format),
             Column::GitStatus => self.git_status(file).render(self.theme),
             Column::SubdirGitRepo(status) => self.subdir_git_repo(file, status).render(self.theme),
             #[cfg(unix)]
